@@ -6,32 +6,8 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2019-2025 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2019-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 
 import argparse
@@ -149,7 +125,7 @@ class Server:
         # signal handers (after forking)
         signal.signal(signal.SIGTERM, partial(self.signal_handler_stop, server))
         signal.signal(signal.SIGINT, partial(self.signal_handler_stop, server))
-        signal.signal(signal.SIGHUP, self.signal_handler_reload)
+        signal.signal(signal.SIGHUP, partial(self.signal_handler_reload, application))
 
         init_request_id_logging(request_id_context)
 
@@ -192,8 +168,9 @@ class Server:
 
         io_loop.add_callback_from_signal(shutdown)
 
-    def signal_handler_reload(self, signal, frame):
+    def signal_handler_reload(self, application, signal, frame):
         log.debug('Reloading service.')
+        application.reload()
         if self.child_id is None:
             for pid in shared_memory.children.values():
                 self.safe_kill(pid, signal)
