@@ -6,32 +6,8 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2019-2025 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2019-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 """
 Sample asynchronous client for the UDM REST API.
 
@@ -295,10 +271,10 @@ class Session:
             yield link
 
     def get_relation(self, entry: dict, relation: str, name: str | None = None, template: dict[str, Any] | None = None) -> dict[str, str]:
-        try:
-            return next(self.get_relations(entry, relation, name, template))
-        except StopIteration:  # pragma: no cover
+        rel = next(self.get_relations(entry, relation, name, template), None)
+        if rel is None:  # pragma: no cover
             raise _NoRelation(relation)
+        return rel
 
     async def resolve_relations(self, entry: dict, relation: str, name: str | None = None, template: dict[str, Any] | None = None) -> AsyncIterator[Any]:
         embedded = entry.get('_embedded', {})
@@ -312,10 +288,10 @@ class Session:
             yield (await self.make_request('GET', rel['href'])).data
 
     async def resolve_relation(self, entry: dict, relation: str, name: str | None = None, template: dict[str, Any] | None = None) -> Any:
-        try:
-            return await anext(self.resolve_relations(entry, relation, name, template))
-        except StopAsyncIteration:  # pragma: no cover
+        rel = await anext(self.resolve_relations(entry, relation, name, template), None)
+        if rel is None:
             raise _NoRelation(relation)
+        return rel
 
 
 class Client:  # noqa: B903
