@@ -6,32 +6,8 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2025 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2017-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 from univention.config_registry import ucr
 from univention.management.console.ldap import get_connection, reset_cache  # noqa: F401
@@ -45,19 +21,27 @@ def get_user_ldap_read_connection(auth_type, binddn, bindpw):
     return get_ldap_connection('user-read', auth_type, binddn, bindpw)
 
 
-def get_machine_ldap_connection(type_):
-    binddn = ucr.get(f'directory/manager/rest/ldap-connection/{type_}/binddn', ucr['ldap/hostdn'])
-    with open(ucr.get(f'directory/manager/rest/ldap-connection/{type_}/password-file', '/etc/machine.secret')) as fd:
+def _get_service_ldap_connection(type_):
+    binddn = ucr.get(f'directory/manager/rest/ldap-connection/{type_}/binddn', ucr['ldap/hostdn'] if type_.startswith('machine-') else f'cn=admin,{ucr["ldap/base"]}')
+    with open(ucr.get(f'directory/manager/rest/ldap-connection/{type_}/password-file', '/etc/machine.secret' if type_.startswith('machine-') else '/etc/ldap.secret')) as fd:
         password = fd.read().strip()
     return get_ldap_connection(type_, None, binddn, password)
 
 
 def get_machine_ldap_write_connection():
-    return get_machine_ldap_connection('machine-write')
+    return _get_service_ldap_connection('machine-write')
 
 
 def get_machine_ldap_read_connection():
-    return get_machine_ldap_connection('machine-read')
+    return _get_service_ldap_connection('machine-read')
+
+
+def get_admin_ldap_write_connection():
+    return _get_service_ldap_connection('admin-write')
+
+
+def get_admin_ldap_read_connection():
+    return _get_service_ldap_connection('admin-read')
 
 
 def get_ldap_connection(type_, auth_type, binddn, bindpw):
